@@ -7,17 +7,17 @@ package DateTime::Language::Norwegian;
 use strict;
 
 use DateTime::Language;
-use vars qw(@ISA @DayNames @DayAbbreviations @MonthNames @MonthAbbreviations @AMPM $VERSION);
+use vars qw(@ISA @DayNames @DayAbbreviations @MonthNames @MonthAbbreviations @AMPM);
 @ISA = qw(DateTime::Language);
 
 
-@MonthNames  = qw(Januar Februar Mars April Mai Juni
-	   Juli August September Oktober November Desember);
+@MonthNames = qw(Januar Februar Mars April Mai Juni
+                 Juli August September Oktober November Desember);
 @MonthAbbreviations = qw(Jan Feb Mar Apr Mai Jun Jul Aug Sep Okt Nov Des);
-@DayNames  = qw(Sndag Mandag Tirsdag Onsdag Torsdag Fredag Lrdag Sndag);
+@DayNames = qw(Sndag Mandag Tirsdag Onsdag Torsdag Fredag Lrdag Sndag);
 @DayAbbreviations = qw(Sn Man Tir Ons Tor Fre Lr Sn);
 
 require DateTime::Language::English;
-@AMPM = @{DateTime::Language::English::AMPM};
+@AMPM = @DateTime::Language::English::AMPM;
 
 1;
